.. Cormoran documentation master file, created by
   sphinx-quickstart on Fri Feb 17 19:49:38 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Cormoran's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 1

   tutorial
   library/index
   releases/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

